# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.chooseDataLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseDataLabel.setObjectName("chooseDataLabel")
        self.horizontalLayout_5.addWidget(self.chooseDataLabel)
        self.chooseDataComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseDataComboBox.setObjectName("chooseDataComboBox")
        self.horizontalLayout_5.addWidget(self.chooseDataComboBox)
        self.gridLayout.addLayout(self.horizontalLayout_5, 0, 0, 1, 1)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.chooseMethodLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseMethodLabel.setObjectName("chooseMethodLabel")
        self.horizontalLayout_4.addWidget(self.chooseMethodLabel)
        self.chooseMethodComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseMethodComboBox.setObjectName("chooseMethodComboBox")
        self.horizontalLayout_4.addWidget(self.chooseMethodComboBox)
        self.gridLayout.addLayout(self.horizontalLayout_4, 1, 0, 1, 1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.chooseXVariableLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseXVariableLabel.setObjectName("chooseXVariableLabel")
        self.horizontalLayout_3.addWidget(self.chooseXVariableLabel)
        self.chooseXVariableComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseXVariableComboBox.setObjectName("chooseXVariableComboBox")
        self.horizontalLayout_3.addWidget(self.chooseXVariableComboBox)
        self.gridLayout.addLayout(self.horizontalLayout_3, 2, 0, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.chooseYVariableLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseYVariableLabel.setObjectName("chooseYVariableLabel")
        self.horizontalLayout_2.addWidget(self.chooseYVariableLabel)
        self.chooseYVariableComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseYVariableComboBox.setObjectName("chooseYVariableComboBox")
        self.horizontalLayout_2.addWidget(self.chooseYVariableComboBox)
        self.gridLayout.addLayout(self.horizontalLayout_2, 2, 1, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.colorCodedVariableLabel = QtWidgets.QLabel(self.groupBox)
        self.colorCodedVariableLabel.setMaximumSize(QtCore.QSize(16777215, 10))
        self.colorCodedVariableLabel.setObjectName("colorCodedVariableLabel")
        self.horizontalLayout.addWidget(self.colorCodedVariableLabel)
        self.colorCodedVariableComboBox = QtWidgets.QComboBox(self.groupBox)
        self.colorCodedVariableComboBox.setObjectName("colorCodedVariableComboBox")
        self.horizontalLayout.addWidget(self.colorCodedVariableComboBox)
        self.gridLayout.addLayout(self.horizontalLayout, 3, 0, 1, 2)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.plotFilenameLabel = QtWidgets.QLabel(self.groupBox)
        self.plotFilenameLabel.setObjectName("plotFilenameLabel")
        self.horizontalLayout_6.addWidget(self.plotFilenameLabel)
        self.plotFilenameLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.plotFilenameLineEdit.setReadOnly(True)
        self.plotFilenameLineEdit.setObjectName("plotFilenameLineEdit")
        self.horizontalLayout_6.addWidget(self.plotFilenameLineEdit)
        self.pushButton = QtWidgets.QPushButton(self.groupBox)
        self.pushButton.setMaximumSize(QtCore.QSize(30, 16777215))
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout_6.addWidget(self.pushButton)
        self.gridLayout.addLayout(self.horizontalLayout_6, 4, 0, 1, 2)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)
        Form.setTabOrder(self.chooseDataComboBox, self.chooseMethodComboBox)
        Form.setTabOrder(self.chooseMethodComboBox, self.chooseXVariableComboBox)
        Form.setTabOrder(self.chooseXVariableComboBox, self.chooseYVariableComboBox)
        Form.setTabOrder(self.chooseYVariableComboBox, self.colorCodedVariableComboBox)
        Form.setTabOrder(self.colorCodedVariableComboBox, self.plotFilenameLineEdit)
        Form.setTabOrder(self.plotFilenameLineEdit, self.pushButton)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Plot ICA/PCA"))
        self.chooseDataLabel.setText(("Choose data"))
        self.chooseMethodLabel.setText(("Choose method"))
        self.chooseXVariableLabel.setText(("Choose X Variable"))
        self.chooseYVariableLabel.setText(("Choose Y Variable"))
        self.colorCodedVariableLabel.setText(("Choose variable to color code points (optional)"))
        self.plotFilenameLabel.setText(("Plot Filename"))
        self.pushButton.setText(("..."))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())

