# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.searchStringLabel = QtWidgets.QLabel(self.groupBox)
        self.searchStringLabel.setObjectName("searchStringLabel")
        self.gridLayout.addWidget(self.searchStringLabel, 0, 0, 1, 1)
        self.searchStringLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.searchStringLineEdit.setObjectName("searchStringLineEdit")
        self.gridLayout.addWidget(self.searchStringLineEdit, 0, 1, 1, 1)
        self.searchDirectoryLabel = QtWidgets.QLabel(self.groupBox)
        self.searchDirectoryLabel.setObjectName("searchDirectoryLabel")
        self.gridLayout.addWidget(self.searchDirectoryLabel, 1, 0, 1, 1)
        self.searchDirectoryLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.searchDirectoryLineEdit.setObjectName("searchDirectoryLineEdit")
        self.gridLayout.addWidget(self.searchDirectoryLineEdit, 1, 1, 1, 1)
        self.searchDirectorypushButton = QtWidgets.QPushButton(self.groupBox)
        self.searchDirectorypushButton.setMaximumSize(QtCore.QSize(30, 16777215))
        self.searchDirectorypushButton.setObjectName("searchDirectorypushButton")
        self.gridLayout.addWidget(self.searchDirectorypushButton, 1, 2, 1, 1)
        self.metadataFilesLabel = QtWidgets.QLabel(self.groupBox)
        self.metadataFilesLabel.setObjectName("metadataFilesLabel")
        self.gridLayout.addWidget(self.metadataFilesLabel, 2, 0, 1, 1)
        self.metadataFilesLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.metadataFilesLineEdit.setObjectName("metadataFilesLineEdit")
        self.gridLayout.addWidget(self.metadataFilesLineEdit, 2, 1, 1, 1)
        self.metadatapushButton = QtWidgets.QPushButton(self.groupBox)
        self.metadatapushButton.setMaximumSize(QtCore.QSize(30, 16777215))
        self.metadatapushButton.setObjectName("metadatapushButton")
        self.gridLayout.addWidget(self.metadatapushButton, 2, 2, 1, 1)
        self.outputFileNameLabel = QtWidgets.QLabel(self.groupBox)
        self.outputFileNameLabel.setObjectName("outputFileNameLabel")
        self.gridLayout.addWidget(self.outputFileNameLabel, 3, 0, 1, 1)
        self.outputFileNameLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.outputFileNameLineEdit.setObjectName("outputFileNameLineEdit")
        self.gridLayout.addWidget(self.outputFileNameLineEdit, 3, 1, 1, 1)
        self.averagesLabel = QtWidgets.QLabel(self.groupBox)
        self.averagesLabel.setObjectName("averagesLabel")
        self.gridLayout.addWidget(self.averagesLabel, 4, 0, 1, 1)
        self.averagesradioButton = QtWidgets.QRadioButton(self.groupBox)
        self.averagesradioButton.setText("")
        self.averagesradioButton.setChecked(True)
        self.averagesradioButton.setObjectName("averagesradioButton")
        self.gridLayout.addWidget(self.averagesradioButton, 4, 1, 1, 1)
        self.singleShotsLabel = QtWidgets.QLabel(self.groupBox)
        self.singleShotsLabel.setObjectName("singleShotsLabel")
        self.gridLayout.addWidget(self.singleShotsLabel, 5, 0, 1, 1)
        self.singleShotsradioButton = QtWidgets.QRadioButton(self.groupBox)
        self.singleShotsradioButton.setText("")
        self.singleShotsradioButton.setObjectName("singleShotsradioButton")
        self.gridLayout.addWidget(self.singleShotsradioButton, 5, 1, 1, 1)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Read ChemCam Data"))
        self.searchStringLabel.setText(("Search String:"))
        self.searchDirectoryLabel.setText(("Search directory:"))
        self.searchDirectorypushButton.setText(("..."))
        self.metadataFilesLabel.setText(("Metadata file(s):"))
        self.metadatapushButton.setText(("..."))
        self.outputFileNameLabel.setText(("Output file name:"))
        self.averagesLabel.setText(("Averages"))
        self.singleShotsLabel.setText(("Single Shots"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())

